MatchMakerActivation.position\_in\_section()
==============================================================

.. currentmodule:: alfred3_interact.page

.. automethod:: MatchMakerActivation.position_in_section
